read

Function read 

pub async fn read<E>(pool: &Pool, instance: E)
where E: Entity + Clone + Debug + Eq + Send,
Tests reading of an entity from the database.

Validates that an entity, once created, can be correctly read from the database. It ensures that the entity does not exist prior to creation and that the retrieved instance matches the created one.