pub async fn create<E>(pool: &Pool, instance: E)Expand description
Tests entity creation in the database.
Verifies that an entity can be created and retrieved correctly. It asserts the non-existence of the entity before creation and checks for equality between the created and retrieved instances.